==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeRegistrationPropertiesExtensionOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesExtensionOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property resourceCreationBegin
 */
public data class ResourceTypeRegistrationPropertiesExtensionOptionsArgs(
    public val resourceCreationBegin: Output<ResourceTypeExtensionOptionsResourceCreationBeginArgs>? =
        null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesExtensionOptionsArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesExtensionOptionsArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesExtensionOptionsArgs.builder()
            .resourceCreationBegin(
                resourceCreationBegin?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ResourceTypeRegistrationPropertiesExtensionOptionsArgs].
 */
@PulumiTagMarker
public class ResourceTypeRegistrationPropertiesExtensionOptionsArgsBuilder internal constructor() {
    private var resourceCreationBegin: Output<ResourceTypeExtensionOptionsResourceCreationBeginArgs>? =
        null

    /**
     * @param value
     */
    @JvmName("egmtwppikhtkmtxs")
    public suspend
    fun resourceCreationBegin(`value`: Output<ResourceTypeExtensionOptionsResourceCreationBeginArgs>) {
        this.resourceCreationBegin = value
    }

    /**
     * @param value
     */
    @JvmName("vfntvnkbqpyegviv")
    public suspend
    fun resourceCreationBegin(`value`: ResourceTypeExtensionOptionsResourceCreationBeginArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceCreationBegin = mapped
    }

    /**
     * @param argument
     */
    @JvmName("klbiliqmuarptqwc")
    public suspend
    fun resourceCreationBegin(argument: suspend ResourceTypeExtensionOptionsResourceCreationBeginArgsBuilder.() -> Unit) {
        val toBeMapped = ResourceTypeExtensionOptionsResourceCreationBeginArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.resourceCreationBegin = mapped
    }

    internal fun build(): ResourceTypeRegistrationPropertiesExtensionOptionsArgs =
        ResourceTypeRegistrationPropertiesExtensionOptionsArgs(
            resourceCreationBegin = resourceCreationBegin,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeRegistrationPropertiesExtensionOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesExtensionOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property resourceCreationBegin
 */
public data class ResourceTypeRegistrationPropertiesExtensionOptionsArgs(
    public val resourceCreationBegin: Output<ResourceTypeExtensionOptionsResourceCreationBeginArgs>? =
        null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesExtensionOptionsArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesExtensionOptionsArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesExtensionOptionsArgs.builder()
            .resourceCreationBegin(
                resourceCreationBegin?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ResourceTypeRegistrationPropertiesExtensionOptionsArgs].
 */
@PulumiTagMarker
public class ResourceTypeRegistrationPropertiesExtensionOptionsArgsBuilder internal constructor() {
    private var resourceCreationBegin: Output<ResourceTypeExtensionOptionsResourceCreationBeginArgs>? =
        null

    /**
     * @param value
     */
    @JvmName("pyrdngcxssmnvexn")
    public suspend
    fun resourceCreationBegin(`value`: Output<ResourceTypeExtensionOptionsResourceCreationBeginArgs>) {
        this.resourceCreationBegin = value
    }

    /**
     * @param value
     */
    @JvmName("thdacetfpodhybav")
    public suspend
    fun resourceCreationBegin(`value`: ResourceTypeExtensionOptionsResourceCreationBeginArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceCreationBegin = mapped
    }

    /**
     * @param argument
     */
    @JvmName("iqcuweoklybsvcab")
    public suspend
    fun resourceCreationBegin(argument: suspend ResourceTypeExtensionOptionsResourceCreationBeginArgsBuilder.() -> Unit) {
        val toBeMapped = ResourceTypeExtensionOptionsResourceCreationBeginArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.resourceCreationBegin = mapped
    }

    internal fun build(): ResourceTypeRegistrationPropertiesExtensionOptionsArgs =
        ResourceTypeRegistrationPropertiesExtensionOptionsArgs(
            resourceCreationBegin = resourceCreationBegin,
        )
}
